==> umbraco-0.0.4.tgz: package/src/index.ts <==
#!/usr/bin/env node

import inquirer from "inquirer";
import path from "path";
import * as fs from "fs";
import { installUmbraco } from "./umbraco/installUmbraco.js";
import { executeInSeries } from "./utils/utils.js";
import { setupFrontend } from "./frontend/setupFrontend.js";
import { initializeGitRepo } from "./generic/initializeGitRepo.js";
import { installDotNetSDK } from "./umbraco/installDotNetSDK.js";
import { createSolutionFile } from "./umbraco/createSolutionFile.js";

const setupProject = async () => {
  try {
    const answers: any = await inquirer.prompt([
      {
        type: "input",
        name: "projectName",
        message: "Enter the project name:",
        validate: (input: string) => (input ? true : "Project name cannot be empty"),
      },
      {
        type: "confirm",
        name: "useUmbraco",
        message: "Do you want to set up the project with Umbraco?",
        default: true,
      },
      {
        type: "list",
        name: "versionChoice",
        message: "Choose the Umbraco version:",
        choices: ["Latest", "Other"],
        when: (answers: any) => answers.useUmbraco,
      },
      {
        type: "list",
        name: "umbracoVersion",
        message: "Choose the Umbraco version:",
        choices: ["13.5.1", "12.3.10", "11.5.0", "10.8.6", "Choose"],
        when: (answers: any) => answers.versionChoice === "Other",
      },
      {
        type: "input",
        name: "ChooseUmbracoVersion",
        message: "Write the Umbraco version:",
        when: (answers: any) => answers.umbracoVersion === "Choose",
        validate: (input: string) => (input ? true : "Umbraco version cannot be empty"),
      },
      {
        type: "list",
        name: "frontendTech",
        message: "Choose the frontend technology:",
        choices: ["Gulp", "Vue", "React"],
      },
      {
        type: "input",
        name: "gitRepo",
        message: "Enter the Git repository URL: (Optional)",
      },
    ]);

    const umbracoVersion =
      answers.versionChoice === "Other"
        ? answers.umbracoVersion === "Choose"
          ? answers.ChooseUmbracoVersion
          : answers.umbracoVersion
        : answers.versionChoice;

    const projectDir = path.join(process.cwd(), answers.projectName);
    const umbracoDir = path.join(projectDir, answers.projectName);

    console.log(`Creating project directory at ${projectDir}...\n`);

    if (!fs.existsSync(projectDir)) {
      fs.mkdirSync(projectDir);
    }

    console.log(`Setting up project in ${projectDir}...\n`);

    const tasks = [
      () => setupFrontend(projectDir, answers),
      () => initializeGitRepo(projectDir, answers),
    ];

    if (answers.useUmbraco) {
      tasks.unshift(
        () => installDotNetSDK(),
        () => installUmbraco(umbracoDir, umbracoVersion),
        () => createSolutionFile(projectDir, umbracoDir, answers)
      );
    }

    await executeInSeries(tasks);
  } catch (err) {
    console.error("Error setting up project:", err);
  }
};

setupProject();

==> umbraco-0.0.6.tgz: package/src/index.ts <==
#!/usr/bin/env node

import inquirer from "inquirer";
import path from "path";
import * as fs from "fs";
import { fileURLToPath } from "url";
import { installUmbraco } from "./umbraco/installUmbraco.js";
import { copyFolderSync, executeInSeries } from "./utils/utils.js";
import { setupFrontend } from "./frontend/setupFrontend.js";
import { initializeGitRepo } from "./generic/initializeGitRepo.js";
import { installDotNetSDK } from "./umbraco/installDotNetSDK.js";
import { createSolutionFile } from "./umbraco/createSolutionFile.js";
import { setupUmbracoTemplate } from "./umbraco/setupUmbracoTemplate.js";

const setupProject = async () => {
  try {
    const __filename = fileURLToPath(import.meta.url);
    const __dirname = path.dirname(__filename);
    copyFolderSync(
      path.join(__dirname, "..", "template"),
      path.join(__dirname, "..", "dist", "template")
    );

    process.stdout.write("\nWelcome to the project setup wizard!\n");

    const answers: any = await inquirer.prompt([
      {
        type: "input",
        name: "projectName",
        message: "Enter the project name:",
        validate: (input: string) => (input ? true : "Project name cannot be empty"),
      },
      {
        type: "confirm",
        name: "useUmbraco",
        message: "Do you want to set up the project with Umbraco?",
        default: true,
      },
      {
        type: "list",
        name: "versionChoice",
        message: "Choose the Umbraco version:",
        choices: ["Latest", "Other"],
        when: (answers: any) => answers.useUmbraco,
      },
      {
        type: "list",
        name: "umbracoVersion",
        message: "Choose the Umbraco version:",
        choices: ["13.5.1", "12.3.10", "11.5.0", "10.8.6", "Choose"],
        when: (answers: any) => answers.versionChoice === "Other",
      },
      {
        type: "input",
        name: "ChooseUmbracoVersion",
        message: "Write the Umbraco version:",
        when: (answers: any) => answers.umbracoVersion === "Choose",
        validate: (input: string) => (input ? true : "Umbraco version cannot be empty"),
      },
      {
        type: "list",
        name: "frontendTech",
        message: "Choose the frontend technology:",
        choices: ["Gulp", "Vue", "React"],
      },
      {
        type: "list",
        name: "frontendTechFramework",
        message: "Do you want to use Next.js or React?",
        when: (answers: any) => answers.frontendTech === "React",
        choices: ["React", "Next.js"],
        default: "React",
      },
      {
        type: "list",
        name: "frontendTechFramework",
        message: "Do you want to use Nuxt.js or standard Vue?",
        when: (answers: any) => answers.frontendTech === "Vue",
        choices: ["Vue", "Nuxt.js"],
        default: "Vue",
      },
      {
        type: "input",
        name: "gitRepo",
        message: "Enter the Git repository URL: (Optional)",
      },
    ]);

    const umbracoVersion =
      answers.versionChoice === "Other"
        ? answers.umbracoVersion === "Choose"
          ? answers.ChooseUmbracoVersion
          : answers.umbracoVersion
        : answers.versionChoice;

    answers.frontendTech = !answers.frontendTechFramework
      ? answers.frontendTech
      : answers.frontendTechFramework;

    const projectDir = path.join(process.cwd(), answers.projectName);
    const umbracoDir = path.join(projectDir, answers.projectName);

    if (!fs.existsSync(projectDir)) {
      fs.mkdirSync(projectDir);
    }
    const tasks = [
      () => setupFrontend(projectDir, answers),
      () => initializeGitRepo(projectDir, answers),
    ];

    if (answers.useUmbraco) {
      tasks.unshift(
        () => installDotNetSDK(),
        () => installUmbraco(umbracoDir, umbracoVersion),
        () => createSolutionFile(projectDir, umbracoDir, answers),
        () => setupUmbracoTemplate(umbracoDir)
      );
    }

    await executeInSeries(tasks);
  } catch (err) {
    console.error("Error setting up project:", err);
  }
};

setupProject();
